==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fshow_user_and_ip-2.2.1.tar.gz: show_user_and_ip/setup.php <==
<?php

function squirrelmail_plugin_init_show_user_and_ip() {
   global $squirrelmail_plugin_hooks;
   $squirrelmail_plugin_hooks['left_main_after']['show_user_and_ip'] = 'show_user_and_ip';
   $squirrelmail_plugin_hooks['right_main_after_header']['show_user_and_ip'] = 'show_last_date_and_ip';
   $squirrelmail_plugin_hooks['loading_prefs']['show_user_and_ip'] = 'last_date_and_ip_load';
   $squirrelmail_plugin_hooks['right_main_bottom']['show_user_and_ip'] = 'last_date_and_ip_save';
   $squirrelmail_plugin_hooks['options_display_inside']['show_user_and_ip'] = 'left_option';
   $squirrelmail_plugin_hooks['options_display_save']['show_user_and_ip'] = 'left_option_save';
   $squirrelmail_plugin_hooks['logout']['show_user_and_ip'] = 'reset_first_login';

}

function show_user_and_ip()
{
  global $username, $show_left_username_ip;

  if( $show_left_username_ip == 1 ) {
    include_once('../functions/i18n.php');
    bindtextdomain('show_user_and_ip', '../plugins/show_user_and_ip/locale');
    textdomain('show_user_and_ip');

    echo '<p><div align="center">';
    echo '<hr>';
    echo '<strong>' . _("Your username:") . '</strong><br>';
    echo $username;
    echo '<br><br>';
    echo '<strong>' . _("Your IP address:") . '</strong><br>';
    echo $_SERVER['REMOTE_ADDR'];
    echo '<hr>';
    echo '</div></p>';
    textdomain('squirrelmail');
  }
}

function last_date_and_ip_load() {
  global $username, $data_dir, $my_last_ip, $my_last_date, $my_page_first_shown, $show_left_username_ip;
  $my_page_first_shown = getPref($data_dir, $username, 'my_page_first_shown');
  $my_last_ip = getPref($data_dir, $username, 'my_last_ip');
  $my_last_date = getPref($data_dir, $username, 'my_last_date');
  $show_left_username_ip = getPref($data_dir, $username, 'show_username_and_ip_on_left');
  if ( strlen($show_left_username_ip) == 0 ) $show_left_username_ip = 0;
}

function show_last_date_and_ip() {
  global $color, $my_last_ip, $my_last_date, $my_page_first_shown, $username;

  if ( $my_page_first_shown == 1 ) {
    $my_display_format = _("D, F j, Y G:i");
    $my_display_date = date(_("D, F j, Y G:i"), $my_last_date);
    include_once('../functions/i18n.php');
    bindtextdomain('show_user_and_ip', '../plugins/show_user_and_ip/locale');
    textdomain('show_user_and_ip');

    if ( !strpos($my_display_format, "F") === false ) {    
      $my_display_date = str_replace("January", _("January"), $my_display_date);
      $my_display_date = str_replace("February", _("February"), $my_display_date);
      $my_display_date = str_replace("March", _("March"), $my_display_date);
      $my_display_date = str_replace("April", _("April"), $my_display_date);
      $my_display_date = str_replace("May", _("May"), $my_display_date);
      $my_display_date = str_replace("June", _("June"), $my_display_date);
      $my_display_date = str_replace("July", _("July"), $my_display_date);
      $my_display_date = str_replace("August", _("August"), $my_display_date);
      $my_display_date = str_replace("September", _("September"), $my_display_date);
      $my_display_date = str_replace("October", _("October"), $my_display_date);
      $my_display_date = str_replace("November", _("November"), $my_display_date);
      $my_display_date = str_replace("December", _("December"), $my_display_date);
    }
    elseif ( !strpos($my_display_format, "M") === false ) {    
      $my_display_date = str_replace("Jan", _("Jan"), $my_display_date);
      $my_display_date = str_replace("Feb", _("Feb"), $my_display_date);
      $my_display_date = str_replace("Mar", _("Mar"), $my_display_date);
      $my_display_date = str_replace("Apr", _("Apr"), $my_display_date);
      $my_display_date = str_replace("May", _("May"), $my_display_date);
      $my_display_date = str_replace("Jun", _("Jun"), $my_display_date);
      $my_display_date = str_replace("Jul", _("Jul"), $my_display_date);
      $my_display_date = str_replace("Aug", _("Aug"), $my_display_date);
      $my_display_date = str_replace("Sep", _("Sep"), $my_display_date);
      $my_display_date = str_replace("Oct", _("Oct"), $my_display_date);
      $my_display_date = str_replace("Nov", _("Nov"), $my_display_date);
      $my_display_date = str_replace("Dec", _("Dec"), $my_display_date);
    }
    
    if ( !strpos($my_display_format, "l") === false ) {
      $my_display_date = str_replace("Monday", _("Monday"), $my_display_date);
      $my_display_date = str_replace("Tuesday", _("Tuesday"), $my_display_date);
      $my_display_date = str_replace("Wednesday", _("Wednesday"), $my_display_date);
      $my_display_date = str_replace("Thursday", _("Thursday"), $my_display_date);
      $my_display_date = str_replace("Friday", _("Friday"), $my_display_date);
      $my_display_date = str_replace("Saturday", _("Saturday"), $my_display_date);
      $my_display_date = str_replace("Sunday", _("Sunday"), $my_display_date);
    }
    elseif ( !strpos($my_display_format, "D") === false ) {
      $my_display_date = str_replace("Mon", _("Mon"), $my_display_date);
      $my_display_date = str_replace("Tue", _("Tue"), $my_display_date);
      $my_display_date = str_replace("Wed", _("Wed"), $my_display_date);
      $my_display_date = str_replace("Thu", _("Thu"), $my_display_date);
      $my_display_date = str_replace("Fri", _("Fri"), $my_display_date);
      $my_display_date = str_replace("Sat", _("Sat"), $my_display_date);
      $my_display_date = str_replace("Sun", _("Sun"), $my_display_date);
    }
   
    echo "<br><table align=center width=\"70%\" cellpadding=0 cellspacing=3 border=0 bgcolor=\"$color[9]\">";
    echo '<tr><td>';
    echo "<table width=\"100%\" cellpadding=5 cellspacing=1 border=0 bgcolor=\"$color[4]\">";
    echo "<tr><td align=center>"; 

    echo _("Welcome") . "<strong> $username</strong>, ";
    echo _("your last connection was from ");
    echo "<strong>$my_last_ip</strong><br>";
    echo _("on");
    echo " <strong> $my_display_date</strong>.";

    textdomain('squirrelmail');

    echo '</td></tr></table></td></tr></table>';
  }
}

function left_option() {
  global $show_left_username_ip;

  include_once('../functions/i18n.php');
  bindtextdomain('show_user_and_ip', '../plugins/show_user_and_ip/locale');
  textdomain('show_user_and_ip');

  echo '<tr><td align="right" nowrap valign="top">' . _("Show My Username and IP under Folders List:");

  textdomain('squirrelmail');
  echo '</td><td>';
  echo '<label><input type="radio" name="check_show_left_username_ip" value="1"';

  if ( $show_left_username_ip == 1) echo ' CHECKED';
  echo '>&nbsp;' . _("Yes") . '</label>&nbsp;&nbsp;&nbsp;&nbsp;';
  echo '<label><input type="radio" name="check_show_left_username_ip"';
  if ( $show_left_username_ip == 0) echo ' CHECKED';
  echo '>&nbsp;' . _("No") . '</label></td></tr>';
}

function left_option_save() {
  global $username, $data_dir;
  if ( $_POST['check_show_left_username_ip'] == 0 ) {
    setPref($data_dir, $username, "show_username_and_ip_on_left", "0");
  }
  elseif ( $_POST['check_show_left_username_ip'] == 1 ) {
    setPref($data_dir, $username, "show_username_and_ip_on_left", "1");
  }
}

function last_date_and_ip_save() {
  global $username, $data_dir, $my_page_first_shown;
  if( $my_page_first_shown == 1 ) {
    $my_last_date = strtotime("now");
    setPref($data_dir, $username, "my_page_first_shown", "0"); 
    setPref($data_dir, $username, "my_last_ip", $_SERVER['REMOTE_ADDR']);
    setPref($data_dir, $username, "my_last_date", $my_last_date); 
  }
}

function reset_first_login() {
  global $username, $data_dir, $my_last_date;
  if( strlen($my_last_date) == 0 ) {
    $my_last_date = strtotime("now");
    setPref($data_dir, $username, "my_page_first_shown", "1"); 
    setPref($data_dir, $username, "my_last_ip", $_SERVER['REMOTE_ADDR']);
    setPref($data_dir, $username, "my_last_date", $my_last_date); 
  }
  else {
    setPref($data_dir, $username, "my_page_first_shown", "1"); 
  }
}

?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fshow_user_and_ip-2.2.2.tar.gz: show_user_and_ip/setup.php <==
<?php

function squirrelmail_plugin_init_show_user_and_ip() {
   global $squirrelmail_plugin_hooks;
   $squirrelmail_plugin_hooks['left_main_after']['show_user_and_ip'] = 'show_user_and_ip';
   $squirrelmail_plugin_hooks['right_main_after_header']['show_user_and_ip'] = 'show_last_date_and_ip';
   $squirrelmail_plugin_hooks['loading_prefs']['show_user_and_ip'] = 'last_date_and_ip_load';
   $squirrelmail_plugin_hooks['right_main_bottom']['show_user_and_ip'] = 'last_date_and_ip_save';
   $squirrelmail_plugin_hooks['options_display_inside']['show_user_and_ip'] = 'left_option';
   $squirrelmail_plugin_hooks['options_display_save']['show_user_and_ip'] = 'left_option_save';
   $squirrelmail_plugin_hooks['logout']['show_user_and_ip'] = 'reset_first_login';

}

function show_user_and_ip_version() {
    return '2.2.2';
}

function show_user_and_ip()
{
  include_once('../plugins/show_user_and_ip/functions.php');
  show_ui();
}

function last_date_and_ip_load() {
  include_once('../plugins/show_user_and_ip/functions.php');
  last_load();
}

function show_last_date_and_ip() {
  include_once('../plugins/show_user_and_ip/functions.php');
  show_last();
}

function left_option() {
  include_once('../plugins/show_user_and_ip/functions.php');
  left_opt();
}

function left_option_save() {
  include_once('../plugins/show_user_and_ip/functions.php');
  left_opt_save();
}

function last_date_and_ip_save() {
  include_once('../plugins/show_user_and_ip/functions.php');
  last_save();
}

function reset_first_login() {
  include_once('../plugins/show_user_and_ip/functions.php');
  reset_fl();
}

?>
